Crate moltenvk_deps

Crate moltenvk_deps 

Structs

Message
Specify callbacks to the user for the install. Can use Default::default()

Enums

Error
Install
Either install silently or with a call messages. Can use Default::default() which gives a default message

Functions

check_or_install
This will check if you have the Vulkan SDK installed by checking if the VULKAN_SDK env var is set. If it’s set then nothing will happen. If it is not set then it will download the latest SDK from lunarg.com and install it at home/.vulkan_sdk. It will then set the required environmnet variables. You can install silently or with a message. Use check_or_install(Default::default()) for an install with a default message